@@ -29,7 +29,7 @@ class HttpError(BaseModel):
 
 
 #
-# JWT
+# LOGIN - JWT
 #
 
 
@@ -44,6 +44,40 @@ class JwtParam(BaseModel):
     role: RoleEnum
 
 
+class MagicLinkDto(BaseModel):
+    email: str
+    firstName: str
+    acceptedTermsAndConditions: bool
+    acceptedGdprTerms: bool
+    acceptedCookiePolicy: bool
+    now: str
+
+
+class MagicLinkDomain(BaseModel):
+    email: EmailStr
+    first_name: str
+    accepted_terms_and_conditions: bool
+    accepted_gdpr_terms: bool
+    accepted_cookie_policy: bool
+    now: str
+
+
+class MagicLinkInternal(BaseModel):
+    magic_link: MagicLinkDomain
+    hash: str
+    source_ip: str
+
+
+class LoginHash(BaseModel):
+    hash: str
+
+
+class WhoAmI(BaseModel):
+    email: EmailStr
+    firstName: str
+    role: RoleEnum
+
+
 #
 # FEATURE REQUEST
 #
